@@ -2,7 +2,7 @@
 LiveJournal OpenId backend, docs at:
     https://python-social-auth.readthedocs.io/en/latest/backends/livejournal.html
 """
-from six.moves.urllib_parse import urlsplit
+from urllib.parse import urlsplit
 
 from .open_id import OpenIdAuth
 from ..exceptions import AuthMissingParameter
@@ -14,10 +14,9 @@ class LiveJournalOpenId(OpenIdAuth):
 
     def get_user_details(self, response):
         """Generate username from identity url"""
-        values = super(LiveJournalOpenId, self).get_user_details(response)
+        values = super().get_user_details(response)
         values['username'] = values.get('username') or \
-                             urlsplit(response.identity_url)\
-                                .netloc.split('.', 1)[0]
+            urlsplit(response.identity_url).netloc.split('.', 1)[0]
         return values
 
     def openid_url(self):
