@@ -1,10 +1,8 @@
-import six
+from urllib.parse import urlencode, unquote
 
 from requests_oauthlib import OAuth1
 from oauthlib.oauth1 import SIGNATURE_TYPE_AUTH_HEADER
 
-from six.moves.urllib_parse import urlencode, unquote
-
 from ..utils import url_add_parameters, parse_qs, handle_http_errors, \
                     constant_time_compare
 from ..exceptions import AuthFailed, AuthCanceled, AuthUnknownError, \
@@ -16,9 +14,9 @@ from .base import BaseAuth
 class OAuthAuth(BaseAuth):
     """OAuth authentication backend base class.
 
-    Also settings will be inspected to get more values names that should be
-    stored on extra_data field. Setting name is created from current backend
-    name (all uppercase) plus _EXTRA_DATA.
+    Settings will be inspected to get more values names that should be
+    stored on extra_data field. The setting name is created following the
+    pattern SOCIAL_AUTH_<uppercase current backend name>_EXTRA_DATA.
 
     access_token is always stored.
 
@@ -41,10 +39,9 @@ class OAuthAuth(BaseAuth):
     def extra_data(self, user, uid, response, details=None, *args, **kwargs):
         """Return access_token and extra defined names to store in
         extra_data field"""
-        data = super(OAuthAuth, self).extra_data(user, uid, response, details,
-                                                 *args, **kwargs)
+        data = super().extra_data(user, uid, response, details, *args, **kwargs)
         data['access_token'] = response.get('access_token', '') or \
-                               kwargs.get('access_token')
+            kwargs.get('access_token')
         return data
 
     def state_token(self):
@@ -142,7 +139,7 @@ class OAuthAuth(BaseAuth):
             params = self.revoke_token_params(token, uid)
             headers = self.revoke_token_headers(token, uid)
             data = urlencode(params) if self.REVOKE_TOKEN_METHOD != 'GET' \
-                                     else None
+                else None
             response = self.request(url, params=params, headers=headers,
                                     data=data, method=self.REVOKE_TOKEN_METHOD)
             return self.process_revoke_token_response(response)
@@ -235,15 +232,11 @@ class BaseOAuth1(OAuthAuth):
         params = self.request_token_extra_arguments()
         params.update(self.get_scope_argument())
         key, secret = self.get_key_and_secret()
-        # decoding='utf-8' produces errors with python-requests on Python3
-        # since the final URL will be of type bytes
-        decoding = None if six.PY3 else 'utf-8'
         state = self.get_or_create_state()
         response = self.request(
             self.REQUEST_TOKEN_URL,
             params=params,
-            auth=OAuth1(key, secret, callback_uri=self.get_redirect_uri(state),
-                        decoding=decoding),
+            auth=OAuth1(key, secret, callback_uri=self.get_redirect_uri(state)),
             method=self.REQUEST_TOKEN_METHOD
         )
         content = response.content
@@ -281,17 +274,13 @@ class BaseOAuth1(OAuthAuth):
         else:
             resource_owner_key = None
             resource_owner_secret = None
-        # decoding='utf-8' produces errors with python-requests on Python3
-        # since the final URL will be of type bytes
-        decoding = None if six.PY3 else 'utf-8'
         state = self.get_or_create_state()
         return OAuth1(key, secret,
                       resource_owner_key=resource_owner_key,
                       resource_owner_secret=resource_owner_secret,
                       callback_uri=self.get_redirect_uri(state),
                       verifier=oauth_verifier,
-                      signature_type=signature_type,
-                      decoding=decoding)
+                      signature_type=signature_type)
 
     def oauth_request(self, token, url, params=None, method='GET'):
         """Generate OAuth request, setups callback url"""
@@ -362,11 +351,9 @@ class BaseOAuth2(OAuthAuth):
     def extra_data(self, user, uid, response, details=None, *args, **kwargs):
         """Return access_token, token_type, and extra defined names to store in
             extra_data field"""
-        data = super(BaseOAuth2, self).extra_data(user, uid, response,
-                                                  details=details,
-                                                  *args, **kwargs)
+        data = super().extra_data(user, uid, response, details=details, *args, **kwargs)
         data['token_type'] = response.get('token_type') or \
-                             kwargs.get('token_type')
+            kwargs.get('token_type')
         return data
 
     def request_access_token(self, *args, **kwargs):
@@ -377,7 +364,7 @@ class BaseOAuth2(OAuthAuth):
             if 'denied' in data['error'] or 'cancelled' in data['error']:
                 raise AuthCanceled(self, data.get('error_description', ''))
             raise AuthFailed(self, data.get('error_description') or
-                                   data['error'])
+                             data['error'])
         elif 'denied' in data:
             raise AuthCanceled(self, data['denied'])
 
