@@ -1,9 +1,4 @@
-import six
-
-
-SERIALIZABLE_TYPES = (dict, list, tuple, set, bool, type(None)) + \
-                     six.integer_types + six.string_types + \
-                     (six.text_type, six.binary_type,)
+SERIALIZABLE_TYPES = (dict, list, tuple, set, bool, type(None), int, str, bytes)
 
 
 def is_dict_type(value):
@@ -69,5 +64,5 @@ def partial_load(strategy, token):
 
         partial.args = [strategy.from_session_value(val) for val in args]
         partial.kwargs = dict((key, strategy.from_session_value(val))
-                            for key, val in kwargs.items())
+                              for key, val in kwargs.items())
     return partial
