@@ -1,14 +1,11 @@
 """Models mixins for Social Auth"""
+import base64
 import re
 import time
-import base64
 import uuid
 import warnings
-
 from datetime import datetime, timedelta
 
-import six
-
 from openid.association import Association as OpenIdAssociation
 
 from .exceptions import MissingBackend
@@ -19,7 +16,7 @@ NO_ASCII_REGEX = re.compile(r'[^\x00-\x7F]+')
 NO_SPECIAL_REGEX = re.compile(r'[^\w.@+_-]+', re.UNICODE)
 
 
-class UserMixin(object):
+class UserMixin:
     # Consider tokens that expire in 5 seconds as already expired
     ACCESS_TOKEN_EXPIRED_THRESHOLD = 5
 
@@ -112,8 +109,7 @@ class UserMixin(object):
 
     def set_extra_data(self, extra_data=None):
         if extra_data and self.extra_data != extra_data:
-            if self.extra_data and not isinstance(
-                    self.extra_data, six.string_types):
+            if self.extra_data and not isinstance(self.extra_data, str):
                 self.extra_data.update(extra_data)
             else:
                 self.extra_data = extra_data
@@ -196,7 +192,7 @@ class UserMixin(object):
         raise NotImplementedError('Implement in subclass')
 
 
-class NonceMixin(object):
+class NonceMixin:
     """One use numbers"""
     server_url = ''
     timestamp = 0
@@ -208,7 +204,7 @@ class NonceMixin(object):
         raise NotImplementedError('Implement in subclass')
 
 
-class AssociationMixin(object):
+class AssociationMixin:
     """OpenId account association"""
     server_url = ''
     handle = ''
@@ -230,9 +226,9 @@ class AssociationMixin(object):
     @classmethod
     def openid_association(cls, assoc):
         secret = assoc.secret
-        if not isinstance(secret, six.binary_type):
+        if not isinstance(secret, bytes):
             secret = secret.encode()
-        return OpenIdAssociation(assoc.handle, base64.decodestring(secret),
+        return OpenIdAssociation(assoc.handle, base64.decodebytes(secret),
                                  assoc.issued, assoc.lifetime,
                                  assoc.assoc_type)
 
@@ -252,7 +248,7 @@ class AssociationMixin(object):
         raise NotImplementedError('Implement in subclass')
 
 
-class CodeMixin(object):
+class CodeMixin:
     email = ''
     code = ''
     verified = False
@@ -279,7 +275,7 @@ class CodeMixin(object):
         raise NotImplementedError('Implement in subclass')
 
 
-class PartialMixin(object):
+class PartialMixin:
     token = ''
     data = ''
     next_step = ''
@@ -331,7 +327,7 @@ class PartialMixin(object):
         return partial
 
 
-class BaseStorage(object):
+class BaseStorage:
     user = UserMixin
     nonce = NonceMixin
     association = AssociationMixin
