@@ -17,21 +17,21 @@ class BrokenBackendTest(unittest.TestCase):
         self.backend = None
 
     def test_auth_url(self):
-        with self.assertRaisesRegexp(NotImplementedError,
-                                     'Implement in subclass'):
+        with self.assertRaisesRegex(NotImplementedError,
+                                    'Implement in subclass'):
             self.backend.auth_url()
 
     def test_auth_html(self):
-        with self.assertRaisesRegexp(NotImplementedError,
-                                     'Implement in subclass'):
+        with self.assertRaisesRegex(NotImplementedError,
+                                    'Implement in subclass'):
             self.backend.auth_html()
 
     def test_auth_complete(self):
-        with self.assertRaisesRegexp(NotImplementedError,
-                                     'Implement in subclass'):
+        with self.assertRaisesRegex(NotImplementedError,
+                                    'Implement in subclass'):
             self.backend.auth_complete()
 
     def test_get_user_details(self):
-        with self.assertRaisesRegexp(NotImplementedError,
-                                     'Implement in subclass'):
+        with self.assertRaisesRegex(NotImplementedError,
+                                    'Implement in subclass'):
             self.backend.get_user_details(None)
