@@ -1,12 +1,10 @@
 import base64
 
-import six
-
 from ..storage import UserMixin, NonceMixin, AssociationMixin, \
-                      CodeMixin, PartialMixin, BaseStorage
+    CodeMixin, PartialMixin, BaseStorage
 
 
-class BaseModel(object):
+class BaseModel:
     @classmethod
     def next_id(cls):
         cls.NEXT_ID += 1
@@ -168,10 +166,7 @@ class TestAssociation(AssociationMixin, BaseModel):
         if assoc is None:
             assoc = TestAssociation(server_url=server_url,
                                     handle=association.handle)
-        if six.PY3:
-            assoc.secret = base64.encodebytes(association.secret)
-        else:
-            assoc.secret = base64.encodestring(association.secret)
+        assoc.secret = base64.encodebytes(association.secret)
         assoc.issued = association.issued
         assoc.lifetime = association.lifetime
         assoc.assoc_type = association.assoc_type
